// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef FCITX5QT5WIDGETSADDONS_VERSION_H
#define FCITX5QT5WIDGETSADDONS_VERSION_H

#define FCITX5QT5WIDGETSADDONS_VERSION_STRING "5.1.8"
#define FCITX5QT5WIDGETSADDONS_VERSION_MAJOR 5
#define FCITX5QT5WIDGETSADDONS_VERSION_MINOR 1
#define FCITX5QT5WIDGETSADDONS_VERSION_PATCH 8
#define FCITX5QT5WIDGETSADDONS_VERSION ((5<<16)|(1<<8)|(8))

#endif
